@@ -30,6 +30,14 @@ class AirzoneInstallation:
         asyncio.create_task(self._conn.get_websocket().open_client())
 
     def get_system_status(self):
+        status = False
+        for device in self.devices:
+            if isinstance(device, AirzoneDevice_az_zone):
+                status = status or device.status.get("power", False)
+
+        return status
+    
+    def get_system_idle(self):
         status = False
         for device in self.devices:
             if isinstance(device, AirzoneDevice_az_zone):
